@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1065 2020/09/25 21:40:55 bcallah Exp $
+# $OpenBSD: Quirks.pm,v 1.1065.2.1 2020/11/27 15:31:57 bket Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -2047,6 +2047,7 @@ my $cve = {
 	'shells/bash' => 'bash-<4.3.27',
 	'sysutils/ansible,-main' => 'ansible-<2.7.1',
 	'sysutils/mcollective' => 'mcollective-<2.5.3',
+	'sysutils/rclone' => 'rclone-<1.53.3',
 	'sysutils/salt' => 'salt-<2018.3.3p2',
 	'telephony/asterisk,-main' => 'asterisk-<13.23.1',
 	'telephony/coturn' => 'turnserver-<4.5.1.2',
